@@ -76,7 +76,7 @@ Event = sa.Table(
     metadata,
     sa.Column('id', sa.INTEGER(), sa.ForeignKey('object.id'), index=True),
     sa.Column('session_id', sa.INTEGER(), sa.ForeignKey('session.session_id')),
-    sa.Column('last_seen', sa.REAL()),
+    sa.Column('last_seen', sa.REAL(), index=True),
     sa.Column('alive', sa.Boolean()),
     sa.Column('lat', sa.REAL()),
     sa.Column('lon', sa.REAL()),
